Changelog
=========

0.1.1 (2011-06-15)
------------------
#. Jmbo rename.

0.1.0
-----
#. Now uses Django 1.2.3.
#. Creates uploads media folder.

0.0.9
-----
#. Corrected django-registration find link

0.0.8
-----
#. Added dummy base template to project app.
#. Added manifest for project app.
#. Default Profile model now inherits from AbstractProfileBase resolving #11. 

0.0.7
-----
#. Set Cheetah version to 2.4.2.1 and above.
